@@ -16,4 +16,4 @@
 # under the License.
 #
 
-cd docker && docker-compose -p kvrocks-controller up -d --force-recreate && cd ..
\ No newline at end of file
+cd docker && docker compose -p kvrocks-controller up -d --force-recreate && cd ..
