@@ -18,4 +18,4 @@
 
 set -e
 
-cd docker && docker-compose -p kvrocks-controller down && cd ..
\ No newline at end of file
+cd docker && docker compose -p kvrocks-controller down && cd ..
