@@ -117,9 +117,9 @@ func (cluster *Cluster) GetShard(shardIndex int) (*Shard, error) {
 	return cluster.Shards[shardIndex], nil
 }
 
-func (cluster *Cluster) AddNode(shardIndex int, addr, role, password string) error {
+func (cluster *Cluster) AddNode(shardIndex int, addr, role, password string) (*ClusterNode, error) {
 	if shardIndex < 0 || shardIndex >= len(cluster.Shards) {
-		return consts.ErrIndexOutOfRange
+		return nil, consts.ErrIndexOutOfRange
 	}
 	return cluster.Shards[shardIndex].addNode(addr, role, password)
 }
@@ -132,7 +132,8 @@ func (cluster *Cluster) RemoveNode(shardIndex int, nodeID string) error {
 }
 
 func (cluster *Cluster) PromoteNewMaster(ctx context.Context,
-	shardIdx int, masterNodeID, preferredNodeID string) (string, error) {
+	shardIdx int, masterNodeID, preferredNodeID string,
+) (string, error) {
 	shard, err := cluster.GetShard(shardIdx)
 	if err != nil {
 		return "", err
@@ -175,17 +176,16 @@ func (cluster *Cluster) Reset(ctx context.Context) error {
 	return nil
 }
 
-func (cluster *Cluster) findShardIndexBySlot(slot int) (int, error) {
-	if slot < 0 || slot > MaxSlotID {
-		return -1, consts.ErrSlotOutOfRange
-	}
+func (cluster *Cluster) findShardIndexBySlot(slot SlotRange) (int, error) {
 	sourceShardIdx := -1
 	for i := 0; i < len(cluster.Shards); i++ {
 		slotRanges := cluster.Shards[i].SlotRanges
 		for _, slotRange := range slotRanges {
-			if slotRange.Contains(slot) {
+			if slotRange.HasOverlap(slot) {
+				if sourceShardIdx != -1 {
+					return sourceShardIdx, consts.ErrSlotRangeBelongsToMultipleShards
+				}
 				sourceShardIdx = i
-				break
 			}
 		}
 	}
@@ -195,7 +195,7 @@ func (cluster *Cluster) findShardIndexBySlot(slot int) (int, error) {
 	return sourceShardIdx, nil
 }
 
-func (cluster *Cluster) MigrateSlot(ctx context.Context, slot int, targetShardIdx int, slotOnly bool) error {
+func (cluster *Cluster) MigrateSlot(ctx context.Context, slot SlotRange, targetShardIdx int, slotOnly bool) error {
 	if targetShardIdx < 0 || targetShardIdx >= len(cluster.Shards) {
 		return consts.ErrIndexOutOfRange
 	}
@@ -207,6 +207,8 @@ func (cluster *Cluster) MigrateSlot(ctx context.Context, slot int, targetShardId
 		return consts.ErrShardIsSame
 	}
 	if slotOnly {
+		// clear source migrating info to avoid mismatch migrating slot error
+		cluster.Shards[sourceShardIdx].ClearMigrateState()
 		cluster.Shards[sourceShardIdx].SlotRanges = RemoveSlotFromSlotRanges(cluster.Shards[sourceShardIdx].SlotRanges, slot)
 		cluster.Shards[targetShardIdx].SlotRanges = AddSlotToSlotRanges(cluster.Shards[targetShardIdx].SlotRanges, slot)
 		return nil
@@ -226,7 +228,7 @@ func (cluster *Cluster) MigrateSlot(ctx context.Context, slot int, targetShardId
 	}
 
 	// Will start the data migration in the background
-	cluster.Shards[sourceShardIdx].MigratingSlot = slot
+	cluster.Shards[sourceShardIdx].MigratingSlot = FromSlotRange(slot)
 	cluster.Shards[sourceShardIdx].TargetShardIndex = targetShardIdx
 	return nil
 }
